# WinterSetup

Software for interacting with the [Wintersense](https://wintersense.com) road surface temperature sensor. Uses WiFi direct to display live readings from device and to configure the device for *remote* mode.

Software can be built for Windows, OSX, and Linux.

## Downloading Dependencies

    npm install
    bower install

## Running the app

To run the app whilst in development mode, you can use the following command whilst in the WinterSetup directory:

    nwbuild -r .

To open devTools for debugging you can right click on the window and select *Inspect*. Or you can add the following to one of your scripts, e.g. in a ```<script>``` tag the index.html file to open devTools straight away:

```js
var gui = require('nw.gui');
gui.Window.get().showDevTools();
```

## Build Notes

Used to build with: 

    nwbuild -p osx64,win64 -v 0.12.3 WinterSetup 

But now use:

    nwbuild -p osx64,win64 WinterSetup

(whilst in the **parent** directory of the WinterSetup directory)

Seemed to be important that I did it without using sudo, thus I had to use the following first in order to have the correct permissions:

    sudo chown -R `whoami` /usr/local


## Icon
 
For the **windows** build adding the "icon" field to the package.json seems to setup the icon ok.

For the **mac** build you will need to do a few things after it has been built:
- To change the icon open 'Get Info' for the built package and drag your custom .icns file on the existing icon.
- To change the icon that appears on a 'alert' then open the package contents and replace Resources/nw.icns (or app.icns and document.icns) with your custom .icns file, give it the same name.



# Database Notes

There are several ways of storing persistent data with NW.js as listed [here](https://github.com/nwjs/nw.js/wiki/Save-persistent-data-in-app).

- **lowdb** stores data to a .json file, which is nice, however you get into all sorts of path difficulties when running in production mode. i.e. when built for Windows it starts looking for the .json file in the Temporary folder from which the code is run for for some reason when the app is started using using the executable.
- **storedb** stores the data to the browser's local storage as a json string
- **pouchdb** trys to store the data to the browser's IndexedDB


Decided to go with storedb, pouchdb could be a good option if more sophistication is needed later down the line, but it's api and the way it returns the documents will take a bit of getting used to.

**Warning** - You'll need to be careful with methods that store to browser, as if you start saving stuff during the development phase that data will still be available when build for production (at least in the mac build).











