(function() {
  'use strict';

  //-------------------------------------------------
  // Encapsulate the storedb global
  //-------------------------------------------------
  angular.module('storedbModule', []).factory('storedb', function() {
    return window.storedb; //storedb must already be loaded on the page
  });


  //-------------------------------------------------
  // Create Module
  //-------------------------------------------------
  angular
    .module('directApp', [
      'ui.router',
      'angularMoment', // angular moment now gets moment from node_modules using require in it's source code.
      'ui.bootstrap',
      'ui.bootstrap.tpls',
      'ngMessages',
      'storedbModule'      
    ]);


  //-------------------------------------------------
  // Configure Routes
  //-------------------------------------------------
  angular
    .module('directApp')
    .config(['$stateProvider', '$urlRouterProvider', routeConfig]);


  // Keep dependencies in sync!
  function routeConfig($stateProvider, $urlRouterProvider) {

    // Set what page we'll default to if the url the user enters is not valid
    $urlRouterProvider.otherwise('/direct');

    $stateProvider

      // Direct
      .state('direct', {
        url: '/direct',
        templateUrl: 'direct/directView.html',
        controller: 'DirectController as directC'
      })

      // Direct
      .state('average', {
        url: '/average',
        templateUrl: 'average/averageView.html',
        controller: 'AverageController as avgC'
      })

      // Config
      .state('config', {
        url: '/config',
        templateUrl: 'config/configView.html',
        controller: 'ConfigController as configC'
      });      


  } //<-.config    


  //-------------------------------------------------
  // Use different moment descriptors
  //-------------------------------------------------
  var moment = require('moment');
  
  moment.locale('en', {
      relativeTime : {
          future: "in %s",
          past:   "%s",
          s:  "just now",
          m:  "a minute ago",
          mm: "%d minutes ago",
          h:  "an hour ago",
          hh: "%d hours ago",
          d:  "a day ago",
          dd: "%d days ago",
          M:  "a month ago",
          MM: "%d months ago",
          y:  "a year ago",
          yy: "%d years ago"
      }
  });


  //-------------------------------------------------
  // Version Number
  //-------------------------------------------------
  // Let's first add the version number as an angular value
  var pjson = require('./package.json');

  angular
    .module('directApp')
    .value('version', pjson.version);

  // Now we'll at it to a controller so we can access it in our index.html file
  angular
    .module('directApp')
    .controller('VersionController',
      ['version', VersionController]);

  // Keep dependencies in sync!
  function VersionController(version) {

    var vm = this;
    vm.version = version;
        
  }//<- Controller




})();//<- IIFE


