(function() {
  'use strict';

  //-------------------------------------------------
  // Package Dependencies
  //-------------------------------------------------
  var dgram       = require('dgram'); // More info here: https://nodejs.org/api/dgram.html
  var udpServer   = dgram.createSocket('udp4');
  var querystring = require('querystring');
  // var aginova     = require('./app/controllers/aginova.js');
  var check       = require('check-types');


  //-------------------------------------------------
  // Create Service
  //-------------------------------------------------
  angular
    .module('directApp')
    .service('directService',
      ['$timeout', '$rootScope', directService]);

  // Keep dependencies in sync!
  function directService($timeout, $rootScope) {

    // Accessible Members Up Top
    /* jshint validthis: true */
    var vm = this;
    vm.latestPacket = {foo: 'bar'};
    vm.msg = 'Hello from service';


    $timeout(function() {
      // vm.latestPacket = {foo: 'Changed'};
      console.log(vm.latestPacket);
    }, 2000);    


    $timeout(function() {
      // vm.latestPacket = {foo: 'Changed Again'};
      console.log(vm.latestPacket);
    }, 4000);    



    //-------------------------------------------------
    // Setup UDP Server
    //-------------------------------------------------

    // Set what port and host the UDP server should watch
    var port = 54521;
    var host = '193.168.101.255'; //<-- Sentinel should always broadcast to this address according to Karl

    // Listening event is emitted when a socket starts listening for datagrams. This happens as soon as UDP sockets
    // are created.
    udpServer.on('listening', function () {
      var address = udpServer.address();
      console.log('UDP Server listening on ' + address.address + ":" + address.port);
    });

    // Error event is emitted when an error occurs
    udpServer.on('error', function () {
      console.log('UDP Error Event!!!!! ');
      console.log("Are you connected to the sentinel?");
    });


    //-------------------------------------------------
    // Sentinel Settings
    //-------------------------------------------------
    // Set up a few defaults for the sentinel
    // This is the address/port on which the sentinel will be waiting for configuration packets
    var sentinelAddress = '193.168.101.1'; // <-- Not sure yet if this will always be fixed?
    var sentinelPort    = 50001; // <-- This should be fixed


    //-------------------------------------------------
    // Message Event
    //-------------------------------------------------
    // A message event is emitted when a new datagram is available on a socket.
    // message - Buffer object. The message.
    // remote  - Object. Remote address information.
    udpServer.on('message', function (message, remote) {
      
      // console.log('\n' +  'Message from ' + remote.address + ':' + remote.port);
      // console.log(Buffer.isBuffer(message));
      // console.log(Buffer.isEncoding('utf8'));

      if (remote.address !== sentinelAddress) {
        throw new Error("It looks as though the sentinels address can change, thus may need to change code");
        // If this gets thrown then you'll want to change the code so the sentinelAddress gets updated.
        // Basically I don't know yet whether the sentinel will always be on ip address 193.168.101.1
      }

      // Convert the message (which is a Buffer) to a string first
      var dataString = message.toString();
      // And then from a query string to a plain old javascript object
      var data = querystring.parse(dataString);


      $rootScope.$apply(function () {
        vm.latestPacket = data;
      });


    });




    //-------------------------------------------------
    // Start Listening
    //-------------------------------------------------
    udpServer.bind(port, host);
    // It does still work if you remove host from this function.




  }//<- Service

})();//<- IIFE














